"""
Memorable: Advanced Memory Engine for LLMs, AI Agents & Multi-Agent Systems

A production-ready memory system combining:
- Memori's easy interceptor-based integration
- Mem0's research-backed techniques
- Supermemory's graph architecture

References:
- Memori: https://github.com/GibsonAI/Memori
- Mem0: https://github.com/mem0ai/mem0
- Supermemory: https://github.com/supermemoryai/supermemory
"""

__version__ = "0.1.1"

from memorable_ai.core.memory_engine import MemoryEngine

__all__ = ["MemoryEngine"]

